@@ -4,6 +4,7 @@
 #include <QtGui>
 #include <QtWebKit>
 #include "glatitude.h"
+#include "gps.h"
 
 class LatitudeGUI : public QMainWindow {
     Q_OBJECT
@@ -15,8 +16,9 @@ public:
 
 private slots:
     void get_loc();
-    void get_cell();
-    void get_gps();
+    void get_acwp();
+    void get_agnss();
+    void get_maemo5();
     void set();
     void set_OK();
     void set_ERROR();
@@ -27,6 +29,7 @@ private slots:
 
 private:
     GoogleLatitude *glatitude;
+    GpsMaemo5 *gps;
     QSettings *setting;
     QWebView *maps;
     QWidget *location;
@@ -37,6 +40,8 @@ private:
     QLineEdit *location_lat;
     QLineEdit *location_lon;
     QLineEdit *location_acc;
+
+    QLineEdit *status;
 };
 
 #endif // LATITUDE_H
